Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(495)

Unified Diff: remoting/protocol/host_message_dispatcher.h

Issue 4313001: Rename classes for Chromoting: (Closed) Base URL: http://git.chromium.org/git/chromium.git
Patch Set: Resolve merge conflicts Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/protocol/fake_session.cc ('k') | remoting/protocol/host_message_dispatcher.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/protocol/host_message_dispatcher.h
diff --git a/remoting/protocol/host_message_dispatcher.h b/remoting/protocol/host_message_dispatcher.h
index 73577234f5fa002da1b766d6e662a9ab94ea1a8b..cd95b264be2d25eeb4cd28d9f9c9efad9f53418f 100644
--- a/remoting/protocol/host_message_dispatcher.h
+++ b/remoting/protocol/host_message_dispatcher.h
@@ -12,7 +12,6 @@
namespace remoting {
-class ChromotocolConnection;
class EventMessage;
class MessageReader;
@@ -21,14 +20,15 @@ namespace protocol {
class ControlMessage;
class HostStub;
class InputStub;
+class Session;
// A message dispatcher used to listen for messages received in
// ChromotocolConnection. It dispatches messages to the corresponding
// handler.
//
// Internally it contains an EventStreamReader that decodes data on
// communications channels into protocol buffer messages.
// EventStreamReader is registered with ChromotocolConnection given to it.
//
// Object of this class is owned by ChromotingHost to dispatch messages
// to itself.
@@ -42,7 +42,7 @@ class HostMessageDispatcher :
// Initialize the message dispatcher with the given connection and
// message handlers.
// Return true if initalization was successful.
- bool Initialize(ChromotocolConnection* connection,
+ bool Initialize(protocol::Session* session,
HostStub* host_stub, InputStub* input_stub);
private:
« no previous file with comments | « remoting/protocol/fake_session.cc ('k') | remoting/protocol/host_message_dispatcher.cc » ('j') | no next file with comments »
@@ -21,14 +20,15 @@ namespace protocol {
// A message dispatcher used to listen for messages received in
-// ChromotocolConnection. It dispatches messages to the corresponding
+// protocol::Session. It dispatches messages to the corresponding
// handler.
//
@@ -21,14 +20,15 @@ namespace protocol {
// Internally it contains an EventStreamReader that decodes data on
// communications channels into protocol buffer messages.
-// EventStreamReader is registered with ChromotocolConnection given to it.
+// EventStreamReader is registered with protocol::Session given to it.
//
// Object of this class is owned by ChromotingHost to dispatch messages

Powered by Google App Engine
This is Rietveld 408576698